/*
 * Class to recursively draw broccoli
 * 
 * From Williams College, CSC 134
 * 
 * Updated by Jim Teresco for CSC 252, The College of Saint Rose, Fall 2013
 * 
 * $Id: BroccoliBranch.java 2244 2013-11-06 04:54:22Z terescoj $ 
 */
import objectdraw.*;
import java.awt.*;

public class BroccoliBranch {

    private static final double TOP_FRACT = 0.8;      // How much broccoli shrinks each call
    private static final double GROWTH_LIMIT = 20.0;  // How little a branch must be before broccoli stops expanding

    private BroccoliBranch left, center, right;       // branches of broccoli
    private AngLine stem;                         // stem of broccoli

    private FilledOval flower;                        // Flower of broccoli plant
    private static final int FLOWER_SIZE = 3;     // The size (width and height) of a flower

    private boolean bigEnough;        // Object big enough to have branches?

    /**
     * Draw broccoli by recursively drawing branches (and flower)
     */
    public BroccoliBranch(Location startLocation, double size, double direction, DrawingCanvas canvas) {
        stem = new AngLine(startLocation,size,direction,canvas);    // Draw stem and color green
        stem.setColor(Color.green);

        Location destLocation = stem.getDest(); // end of stem

        bigEnough = size > GROWTH_LIMIT;

        if (bigEnough) {  // Big enough to keep growing
            left = new BroccoliBranch(destLocation, size * TOP_FRACT,
                direction + Math.PI/9.0, canvas);
            center = new BroccoliBranch(destLocation, size * TOP_FRACT,
                direction, canvas);
            right = new BroccoliBranch(destLocation, size * TOP_FRACT,
                direction - Math.PI/9.0, canvas);
        } 
        else {  // draw flower when small enough
            flower = new FilledOval(destLocation,FLOWER_SIZE,FLOWER_SIZE,canvas);
            flower.setColor(Color.yellow);
        }
    }

    /**
     * @param x,y amount to move broccoli
     */
    public void move(double x, double y) {
        
        stem.move(x,y);     // move stem

        if (bigEnough)  {       // move rest of broccoli - three branches
            left.move(x,y);
            center.move(x,y);
            right.move(x,y);
        } 
        else {                    // move flower
            flower.move(x,y);
        }
    }
}